@@ -8,7 +8,7 @@
  * @brief  a combo box widget re-implemented with a
  *         reset button to switch to a default item
  *
- * @author Copyright (C) 2008-2012 by Gilles Caulier
+ * @author Copyright (C) 2008-2013 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  *
  * This program is free software; you can redistribute it
@@ -46,14 +46,14 @@ class LIBKDCRAW_EXPORT RComboBox : public KHBox
 
 public:
 
-    RComboBox(QWidget* parent=0);
+    RComboBox(QWidget* const parent=0);
     ~RComboBox();
 
     void setCurrentIndex(int d);
-    int  currentIndex();
+    int  currentIndex() const;
 
     void setDefaultIndex(int d);
-    int  defaultIndex();
+    int  defaultIndex() const;
 
     KComboBox* combo() const;
 
@@ -77,8 +77,8 @@ private Q_SLOTS:
 
 private:
 
-    class RComboBoxPriv;
-    RComboBoxPriv* const d;
+    class Private;
+    Private* const d;
 };
 
 }  // namespace KDcrawIface
